function theMovie = twoSpheres(ntstep)
% twoSpheres  Animation of temperature versus time of two spheres with different Bi
%
% Synopsis:   twoSpheres
%             twoSpheres(n)
%             M = twoSpheres(...)
%
% Input:     n = (optional) number of time steps.  Default: n = 45
%
% Output:    M = (optional) MATLAB movie matrix.  Default is to play the movie twice
%                without returning it.  See makeSphereMovie for the short set of instru

if nargin<1, ntstep = 45;  end   %  Provide defaults for optional input

ns = 640;        %  size of the square background
nc = 144;        %  number of elements corresponding to radius of the circles

Bi1 = 10;
alpha1 = 1;       %  order of magnitude of ceramic, m^2/s
Fomax1 = 0.2;

Bi2 = 0.1;
alpha2 = 73;      %  for 2024-T6 Aluminum, m^2/s
Fomax2 = 2;

r0 = 2.5e-2;                    %  radius of sphere, m
tmax1 = Fomax1*r0^2/alpha1;     %  time corresponding to max Fo for material 1
tmax2 = Fomax2*r0^2/alpha2;

tmax = max(tmax1,tmax2);        %  longest time of the simulation

Fo1 = linspace(0,alpha1*tmax/r0^2,ntstep);
Fo2 = linspace(0,alpha2*tmax/r0^2,ntstep);

% --- Assign temperature distributions to the two spheres
T1 = Tsphere(Bi1,Fo1,nc);
T1(:,1) = ones(size(T1,1),1);   %  overwrite initial time with initial condition

T2 = Tsphere(Bi2,Fo2,nc);
T2(:,1) = ones(size(T2,1),1);   %  overwrite initial time with initial condition

% --- set range of colormap
cmin = min([min(T1) min(T2)]);
cmax = max([max(T1) max(T2)]);
caxis([cmin cmax]);

clf;
background = 0.5*(cmin+cmax);
S = background*ones(ns,ns);

ibeg1 = 1 + fix(ns/4 - nc);   %  one quarter of distance from top
jbeg1 = 1 + fix(ns/2 - nc);   %  centered left/right

ibeg2 = 1 + fix(3*ns/4 - nc);   %  three quarters of distance from top
jbeg2 = jbeg1;

if any([ibeg1, ibeg2]<1 )
  error('ibeg1 = %d   ibeg2 = %d  cannot be negative.  Adjust ns or nc',ibeg1,ibeg2);
end  

nt = size(T1,2);
firstTime = 0;     %  flag used to initialize the movie

nf = 0;        %  Frame counter. Allows for loop to run backward if necessary
for k=1:nt

  C = colorCircle(T1(:,k),background);
  [m,n] = size(C);
  S(ibeg1:ibeg1+m-1,jbeg1:jbeg1+n-1) = C;

  C = colorCircle(T2(:,k),background);
  S(ibeg2:ibeg2+m-1,jbeg2:jbeg2+n-1) = C;

%  pcolor(S);   %  pcolor is slower than imagsc
  imagesc(S,[cmin cmax]);
  axis('square');
  colormap('jet');
  colorbar;
  drawnow;

  if firstTime
    M = moviein(nt);
	  firstTime = 0;
  end
  nf = nf + 1;      %  separate counter allows k to be traversed in any order
  M(:,nf) = getframe;

end

if nargout<1      %  show the movie if user doesn't want to save it
  movie(M,2);
else
  theMovie = M;
end

end
