function [zout,Biout] = zRootFirst
% zRootFirst  List smallest roots of 1 - z*cot(z) = Bi for a range of Bi.
%             Compare to Table 5.1 in _Introduction to Heat Transfer_,
%             2nd ed., F.P. Incropera & D.P. De Witt, 1990, Wiley
%
% Synopsis:  zRootFirst
%            z1 = zRootFirst
%            [z1,Bi] = zRootFirst
%
% Input:  none
%
% Output:  z1 = vector of first roots, i.e. roots closest to z=0,
%               of 1 - z*cot(z) = Bi for a range of Bi
%          Bi = vector of Bi values corresponding to z1 values

% --- Use Bi values from Table 5.1 by Incropera and Dewitt
Bi = [0.01:0.01:0.1, 0.15:0.05:0.30, 0.4:0.1:1, 2:1:10, 20:10:50, 100]';
z = zeros(size(Bi));

%  Call optimset to create the data structure that controls fzero
%  Use no messages ('Display','Off') and tight tolerance ('TolX',5e-9)
fzopts = optimset('Display','Off','TolX',5e-12);
zmax = 4;
fprintf('      Bi       z1       f(z1)\n');
for i=1:length(Bi)
  zb = bracket(@zfun,10*eps,zmax,100,Bi(i));  %  2 column matrix
  z(i) = fzero(@zfun,zb(1,:),fzopts,Bi(i));   %  Find root in 1st bracket
  fprintf(' %8.2f  %8.4f  %11.3e\n',Bi(i),z(i),zfun(z(i),Bi(i)));
end
if nargout>0, zout=z(:);    end   %  Optional return arguments
if nargout>1, Biout=Bi(:);  end   %  insure that both are column vectors

end